#define QT_FEATURE_webengine_alsa -1
#define QT_FEATURE_webengine_embedded_build -1
#define QT_FEATURE_webengine_printing_and_pdf 1
#define QT_FEATURE_webengine_kerberos -1
#define QT_FEATURE_webengine_ozone 1
#define QT_FEATURE_webengine_pepper_plugins 1
#define QT_FEATURE_webengine_poppler_cpp 1
#define QT_FEATURE_webengine_proprietary_codecs -1
#define QT_FEATURE_webengine_pulseaudio 1
#define QT_FEATURE_webengine_v8_snapshot_support 1
#define QT_FEATURE_webengine_webrtc 1
#define QT_FEATURE_webengine_webrtc_pipewire -1
